==> haskell-implicit-hie-cradle-0.5.0.1-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie-cradle
version:              0.5.0.1
visibility:           public
id:                   implicit-hie-cradle-0.5.0.1-ENjuVfQCJJvLHHaOspda7C
key:                  implicit-hie-cradle-0.5.0.1-ENjuVfQCJJvLHHaOspda7C
license:              BSD-3-Clause
copyright:            2023
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  49093eb7b4e3fbfdc706df2a2d793294
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie-cradle
hs-libraries:         HSimplicit-hie-cradle-0.5.0.1-ENjuVfQCJJvLHHaOspda7C
depends:
    base-4.17.2.1 directory-1.3.7.1 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK
    filepath-1.4.2.2 hie-bios-0.12.0-9t6nOCQElkXAWha4Ul9ar7
    implicit-hie-0.1.2.7-7KeAYHe4XJv4Gi7fqSsd8k process-1.6.18.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-cradle-0.5.0.1-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie-cradle
version:              0.5.0.1
visibility:           public
id:                   implicit-hie-cradle-0.5.0.1-L1u8yxHrcpA1ONQQ5AI4HK
key:                  implicit-hie-cradle-0.5.0.1-L1u8yxHrcpA1ONQQ5AI4HK
license:              BSD-3-Clause
copyright:            2023
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  0995c103ac805c22177426077f7e9e4e
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie-cradle
hs-libraries:         HSimplicit-hie-cradle-0.5.0.1-L1u8yxHrcpA1ONQQ5AI4HK
depends:
    base-4.17.2.1 directory-1.3.7.1 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK
    filepath-1.4.2.2 hie-bios-0.12.0-CIPKLRwbaluGpbaNawyrJx
    implicit-hie-0.1.2.7-Km5KIZvM2JEI6CYaHDqdhb process-1.6.18.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
